==> library1.4.1.tar.bz2: library/polki/editform.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['polka-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['polka_id'])>5) {puterror($result2['skin'],$TEXT['error-polka6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['polka_id'] = rep($_GET['polka_id']);
$old_polka_id = $_GET['polka_id'];

$query10 = "SELECT * FROM `tbl_polka` WHERE `polka_id`='".$_GET['polka_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl8']); require_once "../utils/bottom_adm.php"; exit();}
   $result_polka = mysqli_fetch_array($result10);
   $polka = $result_polka['polka'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size=30 maxlength=127 type=text name=polka value='<?php echo $polka; ?>'></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=polka_id value='<?php echo $old_polka_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/polki/editform.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['polka-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$button = $TEXT['btn_save'];
$action = "edit.php";

if(strlen($_GET['polka_id'])>5) {puterror($result2['skin'],$TEXT['error-polka6']); require_once "../utils/bottom_adm.php"; exit();}
$_GET['polka_id'] = rep($_GET['polka_id']);
$old_polka_id = $_GET['polka_id'];

$query10 = "SELECT * FROM `tbl_polka` WHERE `polka_id`='".$_GET['polka_id']."' ";
 $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl8']); require_once "../utils/bottom_adm.php"; exit();}
   $result_polka = mysqli_fetch_array($result10);
   $polka = $result_polka['polka'];
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?>:</td><td><input size="30" maxlength="127" type="text" name="polka" value="<?php echo $polka; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="polka_id" value="<?php echo $old_polka_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
